@@ -64,6 +64,8 @@ new EventsRuleToStepFunction(scope: Construct, id: string, props: EventsRuleToSt
 | **Name**     | **Type**        | **Description** |
 |:-------------|:----------------|-----------------|
 |stateMachineProps|[`sfn.StateMachineProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-stepfunctions.StateMachineProps.html)|Optional user provided props to override the default props for sfn.StateMachine|
+|existingEventBusInterface?|[`events.IEventBus`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-events.IEventBus.html)| Optional user-provided custom EventBus for construct to use. Providing both this and `eventBusProps` results an error.|
+|eventBusProps?|[`events.EventBusProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-events.EventBusProps.html)|Optional user-provided properties to override the default properties when creating a custom EventBus. Setting this value to `{}` will create a custom EventBus using all default properties. If neither this nor `existingEventBusInterface` is provided the construct will use the `default` EventBus. Providing both this and `existingEventBusInterface` results an error.|
 |eventRuleProps|[`events.RuleProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-events.RuleProps.html)|User provided eventRuleProps to override the defaults|
 |createCloudWatchAlarms|`boolean`|Whether to create recommended CloudWatch alarms|
 |logGroupProps?|[`logs.LogGroupProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-logs.LogGroupProps.html)|User provided props to override the default props for for the CloudWatchLogs LogGroup.|
@@ -72,6 +74,7 @@ new EventsRuleToStepFunction(scope: Construct, id: string, props: EventsRuleToSt
 
 | **Name**     | **Type**        | **Description** |
 |:-------------|:----------------|-----------------|
+|eventBus?|[`events.IEventBus`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-events.IEventBus.html)|Returns the instance of events.IEventBus used by the construct|
 |eventsRule|[`events.Rule`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-events.Rule.html)|Returns an instance of events.Rule created by the construct|
 |stateMachine|[`sfn.StateMachine`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-stepfunctions.StateMachine.html)|Returns an instance of sfn.StateMachine created by the construct|
 |stateMachineLogGroup|[`logs.ILogGroup`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-logs.ILogGroup.html)|Returns an instance of the ILogGroup created by the construct for StateMachine|
@@ -131,6 +134,8 @@ class EventsRuleToStepFunction(
         event_rule_props: aws_cdk.aws_events.RuleProps,
         state_machine_props: aws_cdk.aws_stepfunctions.StateMachineProps,
         create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
+        event_bus_props: typing.Optional[aws_cdk.aws_events.EventBusProps] = None,
+        existing_event_bus_interface: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
         log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
     ) -> None:
         '''
@@ -139,6 +144,8 @@ class EventsRuleToStepFunction(
         :param event_rule_props: User provided eventRuleProps to override the defaults. Default: - None
         :param state_machine_props: User provided StateMachineProps to override the defaults. Default: - None
         :param create_cloud_watch_alarms: Whether to create recommended CloudWatch alarms. Default: - Alarms are created
+        :param event_bus_props: A new custom EventBus is created with provided props. Default: - None
+        :param existing_event_bus_interface: Existing instance of a custom EventBus. Default: - None
         :param log_group_props: User provided props to override the default props for the CloudWatchLogs LogGroup. Default: - Default props are used
 
         :access: public
@@ -148,6 +155,8 @@ class EventsRuleToStepFunction(
             event_rule_props=event_rule_props,
             state_machine_props=state_machine_props,
             create_cloud_watch_alarms=create_cloud_watch_alarms,
+            event_bus_props=event_bus_props,
+            existing_event_bus_interface=existing_event_bus_interface,
             log_group_props=log_group_props,
         )
 
@@ -175,6 +184,11 @@ class EventsRuleToStepFunction(
     ) -> typing.Optional[typing.List[aws_cdk.aws_cloudwatch.Alarm]]:
         return typing.cast(typing.Optional[typing.List[aws_cdk.aws_cloudwatch.Alarm]], jsii.get(self, "cloudwatchAlarms"))
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="eventBus")
+    def event_bus(self) -> typing.Optional[aws_cdk.aws_events.IEventBus]:
+        return typing.cast(typing.Optional[aws_cdk.aws_events.IEventBus], jsii.get(self, "eventBus"))
+
 
 @jsii.data_type(
     jsii_type="@aws-solutions-constructs/aws-events-rule-step-function.EventsRuleToStepFunctionProps",
@@ -183,6 +197,8 @@ class EventsRuleToStepFunction(
         "event_rule_props": "eventRuleProps",
         "state_machine_props": "stateMachineProps",
         "create_cloud_watch_alarms": "createCloudWatchAlarms",
+        "event_bus_props": "eventBusProps",
+        "existing_event_bus_interface": "existingEventBusInterface",
         "log_group_props": "logGroupProps",
     },
 )
@@ -193,12 +209,16 @@ class EventsRuleToStepFunctionProps:
         event_rule_props: aws_cdk.aws_events.RuleProps,
         state_machine_props: aws_cdk.aws_stepfunctions.StateMachineProps,
         create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
+        event_bus_props: typing.Optional[aws_cdk.aws_events.EventBusProps] = None,
+        existing_event_bus_interface: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
         log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
     ) -> None:
         '''
         :param event_rule_props: User provided eventRuleProps to override the defaults. Default: - None
         :param state_machine_props: User provided StateMachineProps to override the defaults. Default: - None
         :param create_cloud_watch_alarms: Whether to create recommended CloudWatch alarms. Default: - Alarms are created
+        :param event_bus_props: A new custom EventBus is created with provided props. Default: - None
+        :param existing_event_bus_interface: Existing instance of a custom EventBus. Default: - None
         :param log_group_props: User provided props to override the default props for the CloudWatchLogs LogGroup. Default: - Default props are used
 
         :summary: The properties for the EventsRuleToStepFunction Construct
@@ -207,6 +227,8 @@ class EventsRuleToStepFunctionProps:
             event_rule_props = aws_cdk.aws_events.RuleProps(**event_rule_props)
         if isinstance(state_machine_props, dict):
             state_machine_props = aws_cdk.aws_stepfunctions.StateMachineProps(**state_machine_props)
+        if isinstance(event_bus_props, dict):
+            event_bus_props = aws_cdk.aws_events.EventBusProps(**event_bus_props)
         if isinstance(log_group_props, dict):
             log_group_props = aws_cdk.aws_logs.LogGroupProps(**log_group_props)
         self._values: typing.Dict[str, typing.Any] = {
@@ -215,6 +237,10 @@ class EventsRuleToStepFunctionProps:
         }
         if create_cloud_watch_alarms is not None:
             self._values["create_cloud_watch_alarms"] = create_cloud_watch_alarms
+        if event_bus_props is not None:
+            self._values["event_bus_props"] = event_bus_props
+        if existing_event_bus_interface is not None:
+            self._values["existing_event_bus_interface"] = existing_event_bus_interface
         if log_group_props is not None:
             self._values["log_group_props"] = log_group_props
 
@@ -247,6 +273,26 @@ class EventsRuleToStepFunctionProps:
         result = self._values.get("create_cloud_watch_alarms")
         return typing.cast(typing.Optional[builtins.bool], result)
 
+    @builtins.property
+    def event_bus_props(self) -> typing.Optional[aws_cdk.aws_events.EventBusProps]:
+        '''A new custom EventBus is created with provided props.
+
+        :default: - None
+        '''
+        result = self._values.get("event_bus_props")
+        return typing.cast(typing.Optional[aws_cdk.aws_events.EventBusProps], result)
+
+    @builtins.property
+    def existing_event_bus_interface(
+        self,
+    ) -> typing.Optional[aws_cdk.aws_events.IEventBus]:
+        '''Existing instance of a custom EventBus.
+
+        :default: - None
+        '''
+        result = self._values.get("existing_event_bus_interface")
+        return typing.cast(typing.Optional[aws_cdk.aws_events.IEventBus], result)
+
     @builtins.property
     def log_group_props(self) -> typing.Optional[aws_cdk.aws_logs.LogGroupProps]:
         '''User provided props to override the default props for the CloudWatchLogs LogGroup.
